@@ -13,6 +13,8 @@ from numpy import (
     cos,
     sin,
     ndarray,
+    nan,
+    isnan,
     abs as np_abs,
     angle as np_angle,
 )
@@ -204,6 +206,7 @@ def dB_to_dBA(values, freqs):
     ndarray of the converted field
     """
     freq2 = square(freqs)
+    freq2[freq2 == 0] = nan
     RA = (
         12200.0 ** 2
         * freq2 ** 2
@@ -214,7 +217,7 @@ def dB_to_dBA(values, freqs):
         )
     )
     Aweight = 2.0 + 20.0 * log10(RA)
-    Aweight[RA == 0] = -100  # replacing -Inf by -100 dB
+    Aweight[isnan(Aweight)] = -100  # replacing NaN by -100 dB
     Aweight[
         values <= 0
     ] = 0  # avoiding to increase dB in dBA at frequencies where noise is already null
@@ -325,26 +328,24 @@ def rphiz_to_xyz_field(values, phi):
     return column_stack((field_x, field_y, field_z))
 
 
-def time_to_freqs(values):
+def time_to_freqs(values, is_real):
     is_time = True
-    is_positive = False
-    return comp_fft_freqs(values, is_time, is_positive)
+    return comp_fft_freqs(values, is_time, is_real)
 
 
-def freqs_to_time(values):
+def freqs_to_time(values, is_real):
     is_angle = False
-    return comp_fft_time(values, is_angle)
+    return comp_fft_time(values, is_angle, is_real)
 
 
-def angle_to_wavenumber(values):
+def angle_to_wavenumber(values, is_real):
     is_time = False
-    is_positive = False
-    return comp_fft_freqs(values, is_time, is_positive)
+    return comp_fft_freqs(values, is_time, is_real)
 
 
-def wavenumber_to_angle(values):
+def wavenumber_to_angle(values, is_real):
     is_angle = True
-    return comp_fft_time(values, is_angle)
+    return comp_fft_time(values, is_angle, is_real)
 
 
 def xy_to_rphi(x, y):
