@@ -58,12 +58,17 @@ def time_to_freq(self):
                 is_components = False
                 axis_values = results[axis.name]
                 unit = axis.unit
+            if "antiperiod" in axis.symmetries:
+                symmetries = {"period": int(axis.symmetries["antiperiod"] / 2)}
+            else:
+                symmetries = axis.symmetries.copy()
             Axes.append(
                 Data1D(
                     name=name,
                     unit=unit,
                     values=axis_values,
                     is_components=is_components,
+                    symmetries=symmetries,
                 )
             )
         return DataFreq(
@@ -72,4 +77,5 @@ def time_to_freq(self):
             symbol=self.symbol,
             axes=Axes,
             values=values,
+            is_real=self.is_real,
         )
