@@ -1,13 +1,14 @@
 # -*- coding: utf-8 -*-
 from SciDataTool.Functions.conversions import convert
 from SciDataTool.Functions.interpolations import get_common_base
+from SciDataTool.Functions.symmetries import rebuild_symmetries_axis
 from SciDataTool.Classes.DataPattern import DataPattern
 from SciDataTool.Functions import AxisError
 from numpy import array
 from importlib import import_module
 
 
-def get_axis(self, axis):
+def get_axis(self, axis, is_real):
     """Computes the vector 'axis' in the unit required, using conversions and symmetries if needed.
     Parameters
     ----------
@@ -67,6 +68,10 @@ def get_axis(self, axis):
                 is_smallestperiod = False
                 is_oneperiod = True
                 is_antiperiod = False
+        elif self.extension == "rms" or self.extension == "sum":
+            is_smallestperiod = False
+            is_oneperiod = False
+            is_antiperiod = False
         else:
             if self.input_data is not None:
                 axis_values = axis.get_values(is_smallestperiod=True)
@@ -90,6 +95,10 @@ def get_axis(self, axis):
                         is_oneperiod = False
                         is_antiperiod = False
                         self.extension = "interval"
+            elif self.transform == "ifft":  # Ignore symmetries in ifft case
+                is_smallestperiod = True
+                is_oneperiod = False
+                is_antiperiod = False
             else:
                 is_smallestperiod = False
                 is_oneperiod = False
@@ -104,7 +113,8 @@ def get_axis(self, axis):
                         is_oneperiod=is_oneperiod,
                         is_antiperiod=is_antiperiod,
                         is_smallestperiod=is_smallestperiod,
-                    )
+                    ),
+                    is_real=is_real,
                 )
             )
         else:
@@ -134,16 +144,40 @@ def get_axis(self, axis):
             elif "antiperiod" in axis.symmetries:
                 if axis.name != "time":
                     values = values * axis.symmetries["antiperiod"] / 2
+        # Rebuild symmetries in ifft case
+        if self.transform == "ifft":
+            # if "antiperiod" in axis.symmetries:
+            #     axis.symmetries["antiperiod"] = int(axis.symmetries["antiperiod"]/2)
+            if (
+                self.extension != "smallestperiod"
+                and self.extension != "oneperiod"
+                and self.extension != "antiperiod"
+            ):
+                values = rebuild_symmetries_axis(values, axis.symmetries)
+            if "period" in axis.symmetries:
+                if axis.name != "freqs":
+                    values = values * axis.symmetries["period"]
+            elif "antiperiod" in axis.symmetries:
+                if axis.name != "freqs":
+                    values = values * axis.symmetries["antiperiod"] / 2
         # Interpolate axis with input data
         if self.input_data is None:
             self.values = values
         else:
             if len(self.input_data) == 2 and self.extension != "axis_data":
-                self.indices = [
+                indices = [
                     i
                     for i, x in enumerate(values)
                     if x >= self.input_data[0] and x <= self.input_data[-1]
                 ]
+                if self.indices is None:
+                    self.indices = indices
+                else:
+                    indices_new = []
+                    for i in self.indices:
+                        if i in indices:
+                            indices_new.append(i)
+                    self.indices = indices_new
                 self.input_data = None
             else:
                 if self.extension == "axis_data":
@@ -158,3 +192,5 @@ def get_axis(self, axis):
                 self.values = values
         if self.indices is not None:
             self.values = values[self.indices]
+            if self.extension == "sum" or self.extension == "rms":
+                self.indices = None
